Welcome to edam's documentation!
================================

.. toctree::
    :maxdepth: 4
    :caption: Contents

    edam


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
